jobflow.managers
================

jobflow.managers.local
----------------------

.. automodule:: jobflow.managers.local
   :members:
   :undoc-members:
   :show-inheritance:

jobflow.managers.fireworks
--------------------------

.. automodule:: jobflow.managers.fireworks
   :members:
   :show-inheritance:
